package com.rjconsultores.ventaboletos.service.impl;

import java.util.Calendar;
import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.rjconsultores.ventaboletos.dao.ConfRestricaoCanalVentaDAO;
import com.rjconsultores.ventaboletos.entidad.ConfRestricaoCanalVenta;
import com.rjconsultores.ventaboletos.exception.BusinessException;
import com.rjconsultores.ventaboletos.service.ConfRestricaoCanalVentaService;
import com.rjconsultores.ventaboletos.utilerias.UsuarioLogado;

@Service("confRestricaoCanalVentaService")
public class ConfRestricaoCanalVentaServiceImpl implements ConfRestricaoCanalVentaService {
	@Autowired
	private ConfRestricaoCanalVentaDAO confRestricaoCanalVentaDAO;

	public List<ConfRestricaoCanalVenta> obtenerTodos() {
		return confRestricaoCanalVentaDAO.obtenerTodos();
	}

	public ConfRestricaoCanalVenta obtenerID(Integer id) {
		return confRestricaoCanalVentaDAO.obtenerID(id);
	}

	@Transactional
	@Override
	public ConfRestricaoCanalVenta suscribirActualizar(ConfRestricaoCanalVenta entidad) throws BusinessException {
		
		if (StringUtils.isBlank(entidad.getDescConfRestricaoCanalVenta() )){
			throw new BusinessException("confRestricaoCanalVentaService.MSG.descripcionObliga");
		}
		
		if (entidad.getTipoPuntoVenta() == null){
			throw new BusinessException("confRestricaoCanalVentaService.MSG.canalObliga");
		}
		
		//se a ruta no  informada,  obrigatrio informar a origem e destino
		if ( (entidad.getRuta() == null) && ( (entidad.getOrigem() == null) || (entidad.getDestino() == null)) ){
			throw new BusinessException("confRestricaoCanalVentaService.MSG.oriDestObliga");
		}
		
		if ( ((entidad.getOrigem() != null) && (entidad.getDestino() == null)) || ((entidad.getOrigem() == null) && (entidad.getDestino() != null)) ){
			throw new BusinessException("confRestricaoCanalVentaService.MSG.oriDestObliga");
		}
		
		entidad.setUsuarioId(UsuarioLogado.getUsuarioLogado().getUsuarioId());
		entidad.setFecmodif(Calendar.getInstance().getTime());
		entidad.setActivo(Boolean.TRUE);
		
		if (entidad.getConfRestricaoCanalVentaId() == null){
			return confRestricaoCanalVentaDAO.suscribir(entidad);
		}else{
			return confRestricaoCanalVentaDAO.actualizacion(entidad);
		}
	}
	@Transactional
	public void borrar(ConfRestricaoCanalVenta entidad) {
		entidad.setUsuarioId(UsuarioLogado.getUsuarioLogado().getUsuarioId());
		entidad.setFecmodif(Calendar.getInstance().getTime());
		entidad.setActivo(Boolean.FALSE);

		confRestricaoCanalVentaDAO.actualizacion(entidad);
	}

}
